==> suir-component-mapper-3.20.13.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "isRequired", "label", "helperText", "description", "validateOnMount", "meta", "onText", "offText", "className", "FormFieldGridProps", "HelpertextProps", "type"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import clsx from 'clsx';
import { validationError, validationWarning } from '../helpers/helpers';
import FormField from '../form-field/form-field';
var useStyles = createUseStyles({
  root: {
    '&>.field': {
      display: 'inline-block'
    }
  },
  errorLabel: {
    '&:after': {
      content: '"*"',
      color: '#db2828'
    }
  }
});
export var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      description = _useFieldApi.description,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      onText = _useFieldApi.onText,
      offText = _useFieldApi.offText,
      className = _useFieldApi.className,
      FormFieldGridProps = _useFieldApi.FormFieldGridProps,
      HelpertextProps = _useFieldApi.HelpertextProps,
      type = _useFieldApi.type,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  var classes = useStyles();
  var controlLabel = input.checked ? onText : offText;
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    required: isRequired,
    className: clsx(classes.root, className),
    error: invalid && {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  }, rest, {
    label: /*#__PURE__*/React.createElement(FormCheckbox, _extends({
      className: clsx(_defineProperty({}, classes.errorLabel, isRequired)),
      toggle: true,
      label: controlLabel || label
    }, input, {
      disabled: isDisabled,
      onChange: function onChange(event, data) {
        return input.onChange({
          target: data
        });
      }
    }))
  })));
};
Switch.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  onText: PropTypes.node,
  offText: PropTypes.node,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
Switch.defaultProps = {
  FormFieldGridProps: {},
  HelpertextProps: {}
};
export default Switch;

==> suir-component-mapper-4.0.0.tgz: package/esm/switch/switch.js <==
import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "isReadOnly", "isDisabled", "isRequired", "label", "helperText", "description", "validateOnMount", "meta", "onText", "offText", "className", "FormFieldGridProps", "HelpertextProps", "type"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import FormCheckbox from "semantic-ui-react/dist/es/collections/Form/FormCheckbox.js";
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import FormFieldGrid from '../form-field-grid/form-field-grid';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import clsx from 'clsx';
import { validationError, validationWarning } from '../helpers/helpers';
import FormField from '../form-field/form-field';
var useStyles = createUseStyles({
  root: {
    '&>.field': {
      display: 'inline-block'
    }
  },
  errorLabel: {
    '&:after': {
      content: '"*"',
      color: '#db2828'
    }
  }
});
export var Switch = function Switch(props) {
  var _useFieldApi = useFieldApi(_objectSpread(_objectSpread({}, props), {}, {
    type: 'checkbox'
  })),
      input = _useFieldApi.input,
      isReadOnly = _useFieldApi.isReadOnly,
      isDisabled = _useFieldApi.isDisabled,
      isRequired = _useFieldApi.isRequired,
      label = _useFieldApi.label,
      helperText = _useFieldApi.helperText,
      description = _useFieldApi.description,
      validateOnMount = _useFieldApi.validateOnMount,
      meta = _useFieldApi.meta,
      onText = _useFieldApi.onText,
      offText = _useFieldApi.offText,
      className = _useFieldApi.className,
      _useFieldApi$FormFiel = _useFieldApi.FormFieldGridProps,
      FormFieldGridProps = _useFieldApi$FormFiel === void 0 ? {} : _useFieldApi$FormFiel,
      _useFieldApi$Helperte = _useFieldApi.HelpertextProps,
      HelpertextProps = _useFieldApi$Helperte === void 0 ? {} : _useFieldApi$Helperte,
      type = _useFieldApi.type,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var invalid = validationError(meta, validateOnMount);
  var classes = useStyles();
  var controlLabel = input.checked ? onText : offText;
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelpertextProps: HelpertextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    required: isRequired,
    className: clsx(classes.root, className),
    error: invalid && {
      content: meta.error || meta.submitError,
      pointing: 'left'
    }
  }, rest, {
    label: /*#__PURE__*/React.createElement(FormCheckbox, _extends({
      className: clsx(_defineProperty({}, classes.errorLabel, isRequired)),
      toggle: true,
      label: controlLabel || label
    }, input, {
      disabled: isDisabled,
      onChange: function onChange(event, data) {
        return input.onChange({
          target: data
        });
      }
    }))
  })));
};
Switch.propTypes = {
  isReadOnly: PropTypes.bool,
  isDisabled: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  helperText: PropTypes.node,
  validateOnMount: PropTypes.bool,
  onText: PropTypes.node,
  offText: PropTypes.node,
  description: PropTypes.node,

  /** Sub components customization API */
  FormFieldGridProps: PropTypes.object,
  HelpertextProps: PropTypes.object
};
export default Switch;
